@@ -79,12 +79,7 @@ def generate_Holidays(year):
 
     return df
 
-def yearly8760(file_input, shift_DST, year):
-    #read new file - only use specific year's worth of data
-    path, config = os.path.split(file_input)
-    project = file_input.split(os.sep)[-3]
-    read_file = os.path.join(path, project + '_YearlyRates.csv')
-    df = pd.read_csv(read_file, index_col = 'IND', usecols= ['IND', np.str(year)])
+def yearly8760(df, project_name, year, shift_DST):
     
     #initialize dataframe
     df.rename(columns = {np.str(year): 'Rates' }, inplace= True)
@@ -104,7 +99,7 @@ def yearly8760(file_input, shift_DST, year):
         df.set_index(dr, inplace = True)
     else:
         'something wrong with yearly rate calc, give up'
-        print(project + ' Yearly Rate Calc Failed***')
+        print(project_name + ' Yearly Rate Calc Failed***')
         df = pd.DataFrame(np.zeros(len(dr)), index=dr, columns = ['Rates'])
         
     #Reverse DST shift - True for Pvsyst, False for AE data. Rate calc is already DST shifted as is the AE data. Must reverse DST shift for pvsyst
@@ -146,7 +141,7 @@ def yearly8760(file_input, shift_DST, year):
     
     return export
 
-def generate_Rate_column (file_input, shift_DST, year ):
+def generate_Rate_column (project_name, file_input, shift_DST, year):
 
     def generate_rate(df_t1, df_t2, normal_rate_flag, year, shift_DST):
         #  Create DataFrame with Columns of Interest
@@ -343,10 +338,20 @@ def generate_Rate_column (file_input, shift_DST, year ):
     except:
         #rate calc not in config file, redirect to yearly rates file
         normal_rate_flag = False
-        df = yearly8760(file_input, shift_DST, year)
+
+        #read new file - only use specific year's worth of data
+        path, config = os.path.split(file_input)
+        read_file = os.path.join(path, project_name + '_YearlyRates.csv')
+        df = pd.read_csv(read_file, index_col = 'IND', usecols= ['IND', np.str(year)])
+
         if not shift_DST:
-            return df, normal_rate_flag, df, normal_rate_flag
+            df_1 = yearly8760(df.copy(), project_name, year, shift_DST=True)
+            df_2 = yearly8760(df.copy(), project_name, year, shift_DST=False)
+
+            return df_1, normal_rate_flag, df_2, normal_rate_flag
         else:
+            df = yearly8760(df, project_name, year, shift_DST)
+
             return df, normal_rate_flag
     
     if not shift_DST:
