@@ -20,7 +20,12 @@ from time import time
 from typing import Union
 
 from ccrenew.dashboard.data_processing import Bluesky_weather_fucntions_v01 as blu
-from ccrenew.dashboard.data_processing.CCR import all_df_keys as df_keys
+from ccrenew.dashboard import (
+    ccr,
+    all_df_keys
+)
+
+df_keys = all_df_keys
 
 logger = logging.getLogger(__name__)
 
@@ -30,6 +35,18 @@ class FileNotFoundError(Exception):
 class FileOpenError(Exception):
     pass
 
+class project_dict(dict):
+    def __repr__(self):
+        print_str = ''
+        for key, value in self.items():
+            if value.processed:
+                proc = ': Processed'
+            else:
+                proc = ': Unprocessed'
+            print_str = print_str + key + proc + '\n'
+
+        return print_str
+
 
 def dict_insert(dict_, key, value):
     """Checks if a key already exists in dict, creates new key if not.
@@ -59,20 +76,24 @@ def picklefy_project_name(project_name):
     Returns:
         str: The picklefied project name.
     """
-    project_name = re.sub("(,\s)|[,\s]", "_", project_name)
-    project_name = re.sub("[']", "", project_name)
+    project_name = re.sub(r"(,\s)|[,\s]", "_", project_name)
+    project_name = re.sub(r"[']", "", project_name)
 
     return project_name
 
-def get_snow_df(dashboard_folder, data_source):
+def get_snow_df(dashboard_folder, data_source, file_format):
     """Pulls snow data & returns a dataframe. Temporary fix for now, need to
     update path references
 
     Returns:
         DataFrame: Snow data
     """
-    snow_file = os.path.join(dashboard_folder, 'Python_Functions', 'Snow Losses', '{}Operating-States-snowfall.xlsx'.format(data_source))
-    raw_snow_df = read_excel(snow_file)
+    if file_format == 'xlsx':
+        snow_file = os.path.join(dashboard_folder, 'Python_Functions', 'Snow Losses', '{}Operating-States-snowfall.xlsx'.format(data_source))
+        raw_snow_df = read_excel(snow_file, index_col=0)
+    else:
+        snow_file = os.path.join(dashboard_folder, 'Python_Functions', 'Snow Losses', '{}Operating-States-snowfall.csv'.format(data_source))
+        raw_snow_df = read_csv(snow_file, index_col=0)
 
     return raw_snow_df
 
@@ -86,7 +107,7 @@ def retrieve_s3_df(bucket, key):
         return DataFrame()
     return df
 
-def run_bluesky(project_name, start=None, end=None, plot=True):
+def run_bluesky(project_name, start=None, end=None, tran_ghi='add', plot=True):
     """Pulls irradiance & weather data from Solcast for the project & date range.
 
     Args:
@@ -108,19 +129,23 @@ def run_bluesky(project_name, start=None, end=None, plot=True):
         today = datetime.today()
         end = today - timedelta(days=1)
 
-    df_cats,df_units=blu.solcats_to_dash(project_name,start,end,resample=True,convert=False)
-    df_cats = df_cats.tz_localize(None)
+    if tran_ghi != 'only':
+        df_cats,df_units=blu.solcats_to_dash(project_name,start,end,resample=True,convert=False)
+        df_cats = df_cats.tz_localize(None)
 
-    try:
-        df_poa=blu.site_s3_to_poa(project_name, start, end).tz_convert(tz).tz_localize(None)
-        df_cats['sites_ghi_poa'] = df_poa
-        df_cats.loc[:, 'site'] = project_name
-        if plot:
-            df_cats[['poa','ghi', 'sites_ghi_poa']].plot()
-    except IndexError:
-        print('No GHI to transpose! Solcast POA only')
-        if plot:
-            df_cats[['poa','ghi']].plot()    
+    if tran_ghi != 'none':
+        try:
+            df_poa=blu.site_s3_to_poa(project_name, start, end).tz_convert(tz).tz_localize(None)
+            df_cats = DataFrame(df_poa).rename(columns={'poa_global':'sites_ghi_poa'})
+            df_cats.loc[:, 'site'] = project_name
+            if plot:
+                df_cats[['poa','ghi', 'sites_ghi_poa']].plot()
+        except IndexError:
+            print('No GHI to transpose! Solcast POA only')
+            if plot:
+                df_cats[['poa','ghi']].plot()
+        except FileNotFoundError:
+            pass
 
     df_cats.to_clipboard()
     print('\n')
